(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     36877,        857]*)
(*NotebookOutlinePosition[     37515,        879]*)
(*  CellTagsIndexPosition[     37471,        875]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "Lab #1A:  Introduction to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "Title"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as a fancy graphing calculator"
}], "Subtitle"],

Cell[TextData[StyleBox["Copyright (c)  2006, 2008 Kerry Kim, Garrett Odell, \
George von Dassow, and Edwin Munro\nPermission is granted to copy, distribute \
and/or modify this document under the terms of the GNU Free Documentation \
License, Version 1.2 or any later version published by the Free Software \
Foundation; with no Invariant Sections, no Front-Cover Texts, and no \
Back-Cover Texts.  A copy of the license is included in the section entitled \
\"GNU Free Documentation License\"",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Text"],

Cell[CellGroupData[{

Cell["Overview:", "Section"],

Cell[TextData[{
  "\tWelcome!  This file provides a brief overview and tour of some of the \
features of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that you will be using.  In this first lab, point is to demonstrate how \
quickly, easily, and flawlessly ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does complex mathematical operations and calculations.  The main point is \
to get used to seeing the syntax, and to assure yourself that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is powerful, pretty easy to use for simple things, and that the built-in \
functions have names that you expect."
}], "Text"],

Cell[TextData[{
  "\tLet's get started by seeing some basic examples of getting ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to do what you want.  Execute each of the lines of code by moving your \
cursor to the line and pressing Shift+Return.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as a calculator:"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Addition", "Subsubsection"],

Cell[BoxData[
    \(2 + 23\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multiplication is indicated by * or by just leaving a space:", \
"Subsubsection"],

Cell[BoxData[
    \(5\ *\ 2\)], "Input"],

Cell[BoxData[
    \(5\ 2\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " leaves the results of integer division as a fraction:"
}], "Subsubsection"],

Cell[BoxData[
    \(5/7\)], "Input"],

Cell[TextData[{
  "To get the numeric value, enclose with ",
  StyleBox["N[]", "Input"]
}], "Text"],

Cell[BoxData[
    \(N[5/7]\)], "Input"],

Cell[TextData[{
  "In the line above, what you told ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to do was the following:  Evaluate ",
  StyleBox["5/7", "Input"],
  ", then convert it into a decimal-point approximation.  The ",
  StyleBox["N", "Input"],
  " function gives you the numerical value of a number.  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", you call functions by enclosing their arguments in single brackers ",
  StyleBox["[]", "Input"],
  ".\n\nAlternatively, you can do the following:"
}], "Text"],

Cell[BoxData[
    \(5.0/7.0\)], "Input"],

Cell[TextData[{
  "The inclusion of a decimal point tells ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that the number is a floating-point number (as opposed to an exact \
integer) and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will return a similar decimal number (which has precision limited to the \
number of bits available to represent it)"
}], "Text"],

Cell[BoxData[
    \(\((2^ .5)\)\ *\ \((2^ .5)\)\  - 2\)], "Input"],

Cell[TextData[{
  "Here we calculated the square root of two, multiplied it by itself, and \
subtracted two.  We should have got zero, but there is a small amount of \
error due to the limited precision of computers.  Usually, this isn't a \
problem, so don't worry about small round-off errors in conversions.  If you \
think this will be a problem, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has features to help you, but they are cumbersome and somewhat difficult \
to use."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Power is indicated by ^", "Subsubsection"],

Cell[BoxData[
    \(2^3\)], "Input"],

Cell[BoxData[
    \(5^\((1/2)\)\)], "Input"],

Cell[BoxData[
    \(N[5^\((1/2)\)]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " includes a huge selection of built-in functions:"
}], "Subsubsection"],

Cell[TextData[{
  "Most commands in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " have the same or simlar names as the functions you're familliar with.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands are usually an imperative verb or mathematical name, and are \
always capitalized.  Sometimes there are abbreviations (the numerical \
differential equation solver is ",
  StyleBox["NDSolve", "Input"],
  "), but no numbers (i.e. no ode23 or similar).  If you're trying to find a \
specific function, consult the help or make a guess.  Often your guess will \
be correct."
}], "Text"],

Cell[BoxData[
    \(Sqrt[2]\)], "Input"],

Cell[BoxData[
    \(Cos[Pi/4]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is aware of complex numbers:"
}], "Subsubsection"],

Cell[BoxData[
    \(Sqrt[\(-1\)]\)], "Input"],

Cell[BoxData[
    \(I^2\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " remembers definitions:"
}], "Subsubsection"],

Cell[BoxData[
    \(b = 5\)], "Input"],

Cell[BoxData[
    \(b^2 + 3\)], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will replace all future occurances of ",
  StyleBox["b", "Input"],
  " with ",
  StyleBox["5", "Input"],
  ".  This is useful, but can be very annoying as we'll see later.  What we \
have done here is defined a variable, called ",
  StyleBox["b", "Input"],
  " which has the value of 5.  Whenever we use ",
  StyleBox["b", "Input"],
  " subsequently, it's replaced by 5 so ",
  StyleBox["b^2 +3", "Input"],
  " is converted to ",
  StyleBox["5^2+3", "Input"],
  "."
}], "Text"],

Cell[TextData[{
  "One thing to note:  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is case sensitivie, meaning it thinks that ",
  StyleBox["b", "Input"],
  " and ",
  StyleBox["B", "Input"],
  " are two different things:"
}], "Text"],

Cell[BoxData[
    \(b = 5\)], "Input"],

Cell[BoxData[
    \(B = \(-23.5\)\)], "Input"],

Cell[BoxData[
    \(b + 2\)], "Input"],

Cell[BoxData[
    \(B + 2\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Changing variables:", "Subsubsection"],

Cell["\<\
Often, it's useful to change variables.  Suppose we wanted to \
increase the value of b by 2, then we would do:\
\>", "Text"],

Cell[BoxData[
    \(b = b + 2\)], "Input"],

Cell[BoxData[
    \(b\)], "Input"],

Cell[TextData[{
  "Notice that everytime we evaluate the command",
  StyleBox[" b = b + 2", "Input"],
  ", the value of ",
  StyleBox["b", "Input"],
  " increases by 2.  There is a shorthand notation for this:"
}], "Text"],

Cell[BoxData[
    \(b += 2\)], "Input"],

Cell[BoxData[
    \(b\)], "Input"],

Cell["Similarly, we can change b as follows:", "Text"],

Cell[BoxData[
    \(b = b^2\)], "Input"],

Cell[BoxData[
    \(b\)], "Input"],

Cell[BoxData[
    \(b = Sqrt[b]\)], "Input"],

Cell[BoxData[
    \(b\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Graphing with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Subsection"],

Cell[CellGroupData[{

Cell["2-D plots:", "Subsubsection"],

Cell[BoxData[
    \(Plot[Tan\ [x^2], {x, 0, 5}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3-D plots:", "Subsubsection"],

Cell[BoxData[
    \(Plot3D[Sin[x] Cos[y], {x, \(-5\), 5}, {y, \(-5\), 5}]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do your algebra and calculus homework:"
}], "Subsection"],

Cell[TextData[{
  "One of the most powerful features of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is its ability to deal with symbolic mathematica expressions, instead of \
just solving arithmatic problems. Watch how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can instantaneously do calculations that would require great tedium to \
do; we'll start with factoring.  Suppose we wanted to factor the expression \
",
  StyleBox["b^2-1:", "Input"]
}], "Text"],

Cell[BoxData[
    \(Factor[b^2 - 1]\)], "Input"],

Cell[TextData[{
  "What happened here?  We should get ",
  StyleBox["(b+1)(b-1)", "Input"],
  ".  Recall that we defined ",
  StyleBox["b", "Input"],
  " to be ",
  StyleBox["5", "Input"],
  " from earlier, and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " thinks we're asking it to factor the result of ",
  StyleBox["5^2-1", "Input"],
  ", which is ",
  StyleBox["24", "Input"],
  ".  To get around this, we need to make ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to forget that ",
  StyleBox["b", "Input"],
  " is ",
  StyleBox["5", "Input"],
  ".  To do this, we use the ",
  StyleBox["Clear", "Input"],
  " command:"
}], "Text"],

Cell[BoxData[{
    \(Clear[b]\), "\[IndentingNewLine]", 
    \(Factor[b^2 - 1]\)}], "Input"],

Cell["\<\
Now things work properly.  If for some reason the symbolic \
functions below start acting strangely (i.e. returning numbers instaed of \
expressions), you might have defined values for your variables earlier.  Just \
to be safe, it's good practice to Clear any variables you want to use in \
symbolic calculations.\
\>", "Text"],

Cell[BoxData[{
    \(Clear[x, y]\), "\[IndentingNewLine]", 
    \(Expand[\((1 + x + y^2)\)^3]\)}], "Input"],

Cell[BoxData[{
    \(Clear[x]\), "\[IndentingNewLine]", 
    \(Factor[28 + 38\ x - 6\ x\^2 - 21\ x\^3 - 4\ x\^4 + x\^5]\)}], "Input"],

Cell[TextData[{
  "The ",
  StyleBox["Simplify", "Input"],
  " command will usually return the \"simplest\" form of something.  It's \
even aware of obscure trignometric identites:"
}], "Text"],

Cell[BoxData[{
    \(Clear[t]\), "\[IndentingNewLine]", 
    \(Simplify[3  Sin[t] - 4 \((Sin[t]^3)\)]\)}], "Input"],

Cell[CellGroupData[{

Cell["Solving systems of equations:", "Subsubsection"],

Cell[TextData[{
  "Imagine trying to solve the equation ",
  StyleBox["x^4 - 2x^2 +x = 0", "Input"],
  " by hand for the 4 values of ",
  StyleBox["x", "Input"],
  " that satisfy this equation.  Now watch ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " do it:"
}], "Text"],

Cell[BoxData[
    \(Solve[x^4 - 2  x^2 + x \[Equal] 0, x]\)], "Input"],

Cell["How do we verify the solution?  Here's one way:", "Text"],

Cell[BoxData[
    \(x^4 - 2  x^2 + x /. x -> 0.5 \((\(-1\) - Sqrt[5])\)\)], "Input"],

Cell[TextData[{
  "The above statement starts with the original expression above.  The ",
  StyleBox["./", "Input"],
  " tells ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to use the following set of replacement rules.  The ",
  StyleBox["x->", "Input"],
  " specifies a rule that says to replace ",
  StyleBox["x", "Input"],
  " with ",
  StyleBox["0.5(-1-Sqrt[5])", "Input"],
  ".  Indeed, we have found that it equals zero!"
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can solve sets of equations.  To do so, enclose the set of equations in \
curly brackets ",
  StyleBox["{}", "Input"],
  " and use a double equals sign to assert the left hand side of the equation \
is equal to the right hand side (normally, you'd write a single equals sign, \
but you use double equal signs when you're giving ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " a set of equations.  You'll get used to doing this)."
}], "Text"],

Cell[BoxData[
    \(Solve[{x == 5  y + z, y \[Equal] 3  x + 2  z, 
        z^2 - 2  y^2 + 3 \[Equal] x}, {x, y, z}]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary:", "Section"],

Cell[TextData[{
  "Key points of doing this exercise:\n\t-You can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as a sophisticated graphing calculator, and it has many built-in \
functions.\n\t-Built in functions all start with a capital letter, contain no \
numbers or symbols, and are usually an imperative verb or math noun\n\t-You \
call functions by typing the name of the function followed by its arguments \
in brackets [ ]\n\t-Press F1 or the Help key for help\n\t-Press Shirt + Enter \
to evaluate the contents of a cell"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercises:", "Section"],

Cell[TextData[{
  "1.  Using the built in help, or educated guesses, figure out how to get ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to do the following: \n\tCalculate the logarithm of a function\n\tRound a \
number to the nearest integer\n\tGenerate a random number between 2 and 4\n\
Show the commands and their output below"
}], "Text"],

Cell["\<\
Go on to the next lab by opening the file Lab 1B Introduction \
Continued.nb\
\>", "Subsection"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["GNU Free Documentation License\nTo view, Double click \
on the arrow to the right (2nd vertical blue line from the right edge, the \
one with the triangle at the bottom) --->",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Section"],

Cell[TextData[StyleBox["\t\tGNU Free Documentation License\n\t\t  Version \
1.2, November 2002\n\n\n Copyright (C) 2000,2001,2002  Free Software \
Foundation, Inc.\n     51 Franklin St, Fifth Floor, Boston, MA  02110-1301  \
USA\n Everyone is permitted to copy and distribute verbatim copies\n of this \
license document, but changing it is not allowed.\n\n\n0. PREAMBLE\n\nThe \
purpose of this License is to make a manual, textbook, or other\nfunctional \
and useful document \"free\" in the sense of freedom: to\nassure everyone the \
effective freedom to copy and redistribute it,\nwith or without modifying it, \
either commercially or noncommercially.\nSecondarily, this License preserves \
for the author and publisher a way\nto get credit for their work, while not \
being considered responsible\nfor modifications made by others.\n\nThis \
License is a kind of \"copyleft\", which means that derivative\nworks of the \
document must themselves be free in the same sense.  It\ncomplements the GNU \
General Public License, which is a copyleft\nlicense designed for free \
software.\n\nWe have designed this License in order to use it for manuals for \
free\nsoftware, because free software needs free documentation: a free\n\
program should come with manuals providing the same freedoms that the\n\
software does.  But this License is not limited to software manuals;\nit can \
be used for any textual work, regardless of subject matter or\nwhether it is \
published as a printed book.  We recommend this License\nprincipally for \
works whose purpose is instruction or reference.\n\n\n1. APPLICABILITY AND \
DEFINITIONS\n\nThis License applies to any manual or other work, in any \
medium, that\ncontains a notice placed by the copyright holder saying it can \
be\ndistributed under the terms of this License.  Such a notice grants a\n\
world-wide, royalty-free license, unlimited in duration, to use that\nwork \
under the conditions stated herein.  The \"Document\", below,\nrefers to any \
such manual or work.  Any member of the public is a\nlicensee, and is \
addressed as \"you\".  You accept the license if you\ncopy, modify or \
distribute the work in a way requiring permission\nunder copyright law.\n\nA \
\"Modified Version\" of the Document means any work containing the\nDocument \
or a portion of it, either copied verbatim, or with\nmodifications and/or \
translated into another language.\n\nA \"Secondary Section\" is a named \
appendix or a front-matter section of\nthe Document that deals exclusively \
with the relationship of the\npublishers or authors of the Document to the \
Document's overall subject\n(or to related matters) and contains nothing that \
could fall directly\nwithin that overall subject.  (Thus, if the Document is \
in part a\ntextbook of mathematics, a Secondary Section may not explain any\n\
mathematics.)  The relationship could be a matter of historical\nconnection \
with the subject or with related matters, or of legal,\ncommercial, \
philosophical, ethical or political position regarding\nthem.\n\nThe \
\"Invariant Sections\" are certain Secondary Sections whose titles\nare \
designated, as being those of Invariant Sections, in the notice\nthat says \
that the Document is released under this License.  If a\nsection does not fit \
the above definition of Secondary then it is not\nallowed to be designated as \
Invariant.  The Document may contain zero\nInvariant Sections.  If the \
Document does not identify any Invariant\nSections then there are none.\n\n\
The \"Cover Texts\" are certain short passages of text that are listed,\nas \
Front-Cover Texts or Back-Cover Texts, in the notice that says that\nthe \
Document is released under this License.  A Front-Cover Text may\nbe at most \
5 words, and a Back-Cover Text may be at most 25 words.\n\nA \"Transparent\" \
copy of the Document means a machine-readable copy,\nrepresented in a format \
whose specification is available to the\ngeneral public, that is suitable for \
revising the document\nstraightforwardly with generic text editors or (for \
images composed of\npixels) generic paint programs or (for drawings) some \
widely available\ndrawing editor, and that is suitable for input to text \
formatters or\nfor automatic translation to a variety of formats suitable for \
input\nto text formatters.  A copy made in an otherwise Transparent file\n\
format whose markup, or absence of markup, has been arranged to thwart\nor \
discourage subsequent modification by readers is not Transparent.\nAn image \
format is not Transparent if used for any substantial amount\nof text.  A \
copy that is not \"Transparent\" is called \"Opaque\".\n\nExamples of \
suitable formats for Transparent copies include plain\nASCII without markup, \
Texinfo input format, LaTeX input format, SGML\nor XML using a publicly \
available DTD, and standard-conforming simple\nHTML, PostScript or PDF \
designed for human modification.  Examples of\ntransparent image formats \
include PNG, XCF and JPG.  Opaque formats\ninclude proprietary formats that \
can be read and edited only by\nproprietary word processors, SGML or XML for \
which the DTD and/or\nprocessing tools are not generally available, and the\n\
machine-generated HTML, PostScript or PDF produced by some word\nprocessors \
for output purposes only.\n\nThe \"Title Page\" means, for a printed book, \
the title page itself,\nplus such following pages as are needed to hold, \
legibly, the material\nthis License requires to appear in the title page.  \
For works in\nformats which do not have any title page as such, \"Title \
Page\" means\nthe text near the most prominent appearance of the work's \
title,\npreceding the beginning of the body of the text.\n\nA section \
\"Entitled XYZ\" means a named subunit of the Document whose\ntitle either is \
precisely XYZ or contains XYZ in parentheses following\ntext that translates \
XYZ in another language.  (Here XYZ stands for a\nspecific section name \
mentioned below, such as \"Acknowledgements\",\n\"Dedications\", \
\"Endorsements\", or \"History\".)  To \"Preserve the Title\"\nof such a \
section when you modify the Document means that it remains a\nsection \
\"Entitled XYZ\" according to this definition.\n\nThe Document may include \
Warranty Disclaimers next to the notice which\nstates that this License \
applies to the Document.  These Warranty\nDisclaimers are considered to be \
included by reference in this\nLicense, but only as regards disclaiming \
warranties: any other\nimplication that these Warranty Disclaimers may have \
is void and has\nno effect on the meaning of this License.\n\n\n2. VERBATIM \
COPYING\n\nYou may copy and distribute the Document in any medium, either\n\
commercially or noncommercially, provided that this License, the\ncopyright \
notices, and the license notice saying this License applies\nto the Document \
are reproduced in all copies, and that you add no other\nconditions \
whatsoever to those of this License.  You may not use\ntechnical measures to \
obstruct or control the reading or further\ncopying of the copies you make or \
distribute.  However, you may accept\ncompensation in exchange for copies.  \
If you distribute a large enough\nnumber of copies you must also follow the \
conditions in section 3.\n\nYou may also lend copies, under the same \
conditions stated above, and\nyou may publicly display copies.\n\n\n3. \
COPYING IN QUANTITY\n\nIf you publish printed copies (or copies in media that \
commonly have\nprinted covers) of the Document, numbering more than 100, and \
the\nDocument's license notice requires Cover Texts, you must enclose the\n\
copies in covers that carry, clearly and legibly, all these Cover\nTexts: \
Front-Cover Texts on the front cover, and Back-Cover Texts on\nthe back \
cover.  Both covers must also clearly and legibly identify\nyou as the \
publisher of these copies.  The front cover must present\nthe full title with \
all words of the title equally prominent and\nvisible.  You may add other \
material on the covers in addition.\nCopying with changes limited to the \
covers, as long as they preserve\nthe title of the Document and satisfy these \
conditions, can be treated\nas verbatim copying in other respects.\n\nIf the \
required texts for either cover are too voluminous to fit\nlegibly, you \
should put the first ones listed (as many as fit\nreasonably) on the actual \
cover, and continue the rest onto adjacent\npages.\n\nIf you publish or \
distribute Opaque copies of the Document numbering\nmore than 100, you must \
either include a machine-readable Transparent\ncopy along with each Opaque \
copy, or state in or with each Opaque copy\na computer-network location from \
which the general network-using\npublic has access to download using \
public-standard network protocols\na complete Transparent copy of the \
Document, free of added material.\nIf you use the latter option, you must \
take reasonably prudent steps,\nwhen you begin distribution of Opaque copies \
in quantity, to ensure\nthat this Transparent copy will remain thus \
accessible at the stated\nlocation until at least one year after the last \
time you distribute an\nOpaque copy (directly or through your agents or \
retailers) of that\nedition to the public.\n\nIt is requested, but not \
required, that you contact the authors of the\nDocument well before \
redistributing any large number of copies, to give\nthem a chance to provide \
you with an updated version of the Document.\n\n\n4. MODIFICATIONS\n\nYou may \
copy and distribute a Modified Version of the Document under\nthe conditions \
of sections 2 and 3 above, provided that you release\nthe Modified Version \
under precisely this License, with the Modified\nVersion filling the role of \
the Document, thus licensing distribution\nand modification of the Modified \
Version to whoever possesses a copy\nof it.  In addition, you must do these \
things in the Modified Version:\n\nA. Use in the Title Page (and on the \
covers, if any) a title distinct\n   from that of the Document, and from \
those of previous versions\n   (which should, if there were any, be listed in \
the History section\n   of the Document).  You may use the same title as a \
previous version\n   if the original publisher of that version gives \
permission.\nB. List on the Title Page, as authors, one or more persons or \
entities\n   responsible for authorship of the modifications in the Modified\n\
   Version, together with at least five of the principal authors of the\n   \
Document (all of its principal authors, if it has fewer than five),\n   \
unless they release you from this requirement.\nC. State on the Title page \
the name of the publisher of the\n   Modified Version, as the publisher.\nD. \
Preserve all the copyright notices of the Document.\nE. Add an appropriate \
copyright notice for your modifications\n   adjacent to the other copyright \
notices.\nF. Include, immediately after the copyright notices, a license \
notice\n   giving the public permission to use the Modified Version under the\
\n   terms of this License, in the form shown in the Addendum below.\nG. \
Preserve in that license notice the full lists of Invariant Sections\n   and \
required Cover Texts given in the Document's license notice.\nH. Include an \
unaltered copy of this License.\nI. Preserve the section Entitled \
\"History\", Preserve its Title, and add\n   to it an item stating at least \
the title, year, new authors, and\n   publisher of the Modified Version as \
given on the Title Page.  If\n   there is no section Entitled \"History\" in \
the Document, create one\n   stating the title, year, authors, and publisher \
of the Document as\n   given on its Title Page, then add an item describing \
the Modified\n   Version as stated in the previous sentence.\nJ. Preserve the \
network location, if any, given in the Document for\n   public access to a \
Transparent copy of the Document, and likewise\n   the network locations \
given in the Document for previous versions\n   it was based on.  These may \
be placed in the \"History\" section.\n   You may omit a network location for \
a work that was published at\n   least four years before the Document itself, \
or if the original\n   publisher of the version it refers to gives \
permission.\nK. For any section Entitled \"Acknowledgements\" or \
\"Dedications\",\n   Preserve the Title of the section, and preserve in the \
section all\n   the substance and tone of each of the contributor \
acknowledgements\n   and/or dedications given therein.\nL. Preserve all the \
Invariant Sections of the Document,\n   unaltered in their text and in their \
titles.  Section numbers\n   or the equivalent are not considered part of the \
section titles.\nM. Delete any section Entitled \"Endorsements\".  Such a \
section\n   may not be included in the Modified Version.\nN. Do not retitle \
any existing section to be Entitled \"Endorsements\"\n   or to conflict in \
title with any Invariant Section.\nO. Preserve any Warranty Disclaimers.\n\n\
If the Modified Version includes new front-matter sections or\nappendices \
that qualify as Secondary Sections and contain no material\ncopied from the \
Document, you may at your option designate some or all\nof these sections as \
invariant.  To do this, add their titles to the\nlist of Invariant Sections \
in the Modified Version's license notice.\nThese titles must be distinct from \
any other section titles.\n\nYou may add a section Entitled \"Endorsements\", \
provided it contains\nnothing but endorsements of your Modified Version by \
various\nparties--for example, statements of peer review or that the text has\
\nbeen approved by an organization as the authoritative definition of a\n\
standard.\n\nYou may add a passage of up to five words as a Front-Cover Text, \
and a\npassage of up to 25 words as a Back-Cover Text, to the end of the list\
\nof Cover Texts in the Modified Version.  Only one passage of\nFront-Cover \
Text and one of Back-Cover Text may be added by (or\nthrough arrangements \
made by) any one entity.  If the Document already\nincludes a cover text for \
the same cover, previously added by you or\nby arrangement made by the same \
entity you are acting on behalf of,\nyou may not add another; but you may \
replace the old one, on explicit\npermission from the previous publisher that \
added the old one.\n\nThe author(s) and publisher(s) of the Document do not \
by this License\ngive permission to use their names for publicity for or to \
assert or\nimply endorsement of any Modified Version.\n\n\n5. COMBINING \
DOCUMENTS\n\nYou may combine the Document with other documents released under \
this\nLicense, under the terms defined in section 4 above for modified\n\
versions, provided that you include in the combination all of the\nInvariant \
Sections of all of the original documents, unmodified, and\nlist them all as \
Invariant Sections of your combined work in its\nlicense notice, and that you \
preserve all their Warranty Disclaimers.\n\nThe combined work need only \
contain one copy of this License, and\nmultiple identical Invariant Sections \
may be replaced with a single\ncopy.  If there are multiple Invariant \
Sections with the same name but\ndifferent contents, make the title of each \
such section unique by\nadding at the end of it, in parentheses, the name of \
the original\nauthor or publisher of that section if known, or else a unique \
number.\nMake the same adjustment to the section titles in the list of\n\
Invariant Sections in the license notice of the combined work.\n\nIn the \
combination, you must combine any sections Entitled \"History\"\nin the \
various original documents, forming one section Entitled\n\"History\"; \
likewise combine any sections Entitled \"Acknowledgements\",\nand any \
sections Entitled \"Dedications\".  You must delete all sections\nEntitled \
\"Endorsements\".\n\n\n6. COLLECTIONS OF DOCUMENTS\n\nYou may make a \
collection consisting of the Document and other documents\nreleased under \
this License, and replace the individual copies of this\nLicense in the \
various documents with a single copy that is included in\nthe collection, \
provided that you follow the rules of this License for\nverbatim copying of \
each of the documents in all other respects.\n\nYou may extract a single \
document from such a collection, and distribute\nit individually under this \
License, provided you insert a copy of this\nLicense into the extracted \
document, and follow this License in all\nother respects regarding verbatim \
copying of that document.\n\n\n7. AGGREGATION WITH INDEPENDENT WORKS\n\nA \
compilation of the Document or its derivatives with other separate\nand \
independent documents or works, in or on a volume of a storage or\n\
distribution medium, is called an \"aggregate\" if the copyright\nresulting \
from the compilation is not used to limit the legal rights\nof the \
compilation's users beyond what the individual works permit.\nWhen the \
Document is included in an aggregate, this License does not\napply to the \
other works in the aggregate which are not themselves\nderivative works of \
the Document.\n\nIf the Cover Text requirement of section 3 is applicable to \
these\ncopies of the Document, then if the Document is less than one half of\n\
the entire aggregate, the Document's Cover Texts may be placed on\ncovers \
that bracket the Document within the aggregate, or the\nelectronic equivalent \
of covers if the Document is in electronic form.\nOtherwise they must appear \
on printed covers that bracket the whole\naggregate.\n\n\n8. TRANSLATION\n\n\
Translation is considered a kind of modification, so you may\ndistribute \
translations of the Document under the terms of section 4.\nReplacing \
Invariant Sections with translations requires special\npermission from their \
copyright holders, but you may include\ntranslations of some or all Invariant \
Sections in addition to the\noriginal versions of these Invariant Sections.  \
You may include a\ntranslation of this License, and all the license notices \
in the\nDocument, and any Warranty Disclaimers, provided that you also \
include\nthe original English version of this License and the original \
versions\nof those notices and disclaimers.  In case of a disagreement \
between\nthe translation and the original version of this License or a notice\
\nor disclaimer, the original version will prevail.\n\nIf a section in the \
Document is Entitled \"Acknowledgements\",\n\"Dedications\", or \"History\", \
the requirement (section 4) to Preserve\nits Title (section 1) will typically \
require changing the actual\ntitle.\n\n\n9. TERMINATION\n\nYou may not copy, \
modify, sublicense, or distribute the Document except\nas expressly provided \
for under this License.  Any other attempt to\ncopy, modify, sublicense or \
distribute the Document is void, and will\nautomatically terminate your \
rights under this License.  However,\nparties who have received copies, or \
rights, from you under this\nLicense will not have their licenses terminated \
so long as such\nparties remain in full compliance.\n\n\n10. FUTURE REVISIONS \
OF THIS LICENSE\n\nThe Free Software Foundation may publish new, revised \
versions\nof the GNU Free Documentation License from time to time.  Such new\n\
versions will be similar in spirit to the present version, but may\ndiffer in \
detail to address new problems or concerns.  See\n\
http://www.gnu.org/copyleft/.\n\nEach version of the License is given a \
distinguishing version number.\nIf the Document specifies that a particular \
numbered version of this\nLicense \"or any later version\" applies to it, you \
have the option of\nfollowing the terms and conditions either of that \
specified version or\nof any later version that has been published (not as a \
draft) by the\nFree Software Foundation.  If the Document does not specify a \
version\nnumber of this License, you may choose any version ever published \
(not\nas a draft) by the Free Software Foundation.\n\n\nADDENDUM: How to use \
this License for your documents\n\nTo use this License in a document you have \
written, include a copy of\nthe License in the document and put the following \
copyright and\nlicense notices just after the title page:\n\n    Copyright \
(c)  YEAR  YOUR NAME.\n    Permission is granted to copy, distribute and/or \
modify this document\n    under the terms of the GNU Free Documentation \
License, Version 1.2\n    or any later version published by the Free Software \
Foundation;\n    with no Invariant Sections, no Front-Cover Texts, and no \
Back-Cover Texts.\n    A copy of the license is included in the section \
entitled \"GNU\n    Free Documentation License\".\n\nIf you have Invariant \
Sections, Front-Cover Texts and Back-Cover Texts,\nreplace the \
\"with...Texts.\" line with this:\n\n    with the Invariant Sections being \
LIST THEIR TITLES, with the\n    Front-Cover Texts being LIST, and with the \
Back-Cover Texts being LIST.\n\nIf you have Invariant Sections without Cover \
Texts, or some other\ncombination of the three, merge those two alternatives \
to suit the\nsituation.\n\nIf your document contains nontrivial examples of \
program code, we\nrecommend releasing these examples in parallel under your \
choice of\nfree software license, such as the GNU General Public License,\nto \
permit their use in free software.\n",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1625}, {0, 1028}},
WindowSize->{988, 669},
WindowMargins->{{Automatic, 176}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 111, 4, 88, "Title"],
Cell[1890, 59, 119, 4, 52, "Subtitle"],
Cell[2012, 65, 552, 8, 94, "Text"],

Cell[CellGroupData[{
Cell[2589, 77, 28, 0, 69, "Section"],
Cell[2620, 79, 651, 15, 66, "Text"],
Cell[3274, 96, 272, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[3571, 106, 107, 4, 38, "Subsection"],

Cell[CellGroupData[{
Cell[3703, 114, 33, 0, 28, "Subsubsection"],
Cell[3739, 116, 39, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3815, 122, 87, 1, 28, "Subsubsection"],
Cell[3905, 125, 40, 1, 27, "Input"],
Cell[3948, 128, 37, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4022, 134, 147, 4, 28, "Subsubsection"],
Cell[4172, 140, 36, 1, 27, "Input"],
Cell[4211, 143, 99, 3, 31, "Text"],
Cell[4313, 148, 39, 1, 27, "Input"],
Cell[4355, 151, 546, 14, 82, "Text"],
Cell[4904, 167, 40, 1, 27, "Input"],
Cell[4947, 170, 387, 10, 48, "Text"],
Cell[5337, 182, 66, 1, 27, "Input"],
Cell[5406, 185, 505, 10, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5948, 200, 48, 0, 28, "Subsubsection"],
Cell[5999, 202, 36, 1, 27, "Input"],
Cell[6038, 205, 44, 1, 27, "Input"],
Cell[6085, 208, 47, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6169, 214, 142, 4, 28, "Subsubsection"],
Cell[6314, 220, 617, 14, 65, "Text"],
Cell[6934, 236, 40, 1, 27, "Input"],
Cell[6977, 239, 42, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7056, 245, 122, 4, 28, "Subsubsection"],
Cell[7181, 251, 45, 1, 27, "Input"],
Cell[7229, 254, 36, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7302, 260, 116, 4, 28, "Subsubsection"],
Cell[7421, 266, 38, 1, 27, "Input"],
Cell[7462, 269, 40, 1, 27, "Input"],
Cell[7505, 272, 549, 17, 49, "Text"],
Cell[8057, 291, 249, 9, 32, "Text"],
Cell[8309, 302, 38, 1, 27, "Input"],
Cell[8350, 305, 46, 1, 27, "Input"],
Cell[8399, 308, 38, 1, 27, "Input"],
Cell[8440, 311, 38, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8515, 317, 44, 0, 28, "Subsubsection"],
Cell[8562, 319, 135, 3, 30, "Text"],
Cell[8700, 324, 42, 1, 27, "Input"],
Cell[8745, 327, 34, 1, 27, "Input"],
Cell[8782, 330, 222, 6, 31, "Text"],
Cell[9007, 338, 39, 1, 27, "Input"],
Cell[9049, 341, 34, 1, 27, "Input"],
Cell[9086, 344, 54, 0, 30, "Text"],
Cell[9143, 346, 40, 1, 27, "Input"],
Cell[9186, 349, 34, 1, 27, "Input"],
Cell[9223, 352, 44, 1, 27, "Input"],
Cell[9270, 355, 34, 1, 27, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9353, 362, 111, 5, 38, "Subsection"],

Cell[CellGroupData[{
Cell[9489, 371, 35, 0, 28, "Subsubsection"],
Cell[9527, 373, 60, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9624, 379, 35, 0, 28, "Subsubsection"],
Cell[9662, 381, 86, 1, 27, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9797, 388, 133, 4, 38, "Subsection"],
Cell[9933, 394, 488, 12, 49, "Text"],
Cell[10424, 408, 48, 1, 27, "Input"],
Cell[10475, 411, 662, 24, 50, "Text"],
Cell[11140, 437, 92, 2, 43, "Input"],
Cell[11235, 441, 338, 6, 46, "Text"],
Cell[11576, 449, 107, 2, 43, "Input"],
Cell[11686, 453, 133, 2, 47, "Input"],
Cell[11822, 457, 193, 5, 31, "Text"],
Cell[12018, 464, 115, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[12158, 470, 54, 0, 28, "Subsubsection"],
Cell[12215, 472, 283, 9, 32, "Text"],
Cell[12501, 483, 70, 1, 27, "Input"],
Cell[12574, 486, 63, 0, 30, "Text"],
Cell[12640, 488, 84, 1, 27, "Input"],
Cell[12727, 491, 453, 13, 49, "Text"],
Cell[13183, 506, 524, 12, 50, "Text"],
Cell[13710, 520, 128, 2, 27, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13899, 529, 27, 0, 69, "Section"],
Cell[13929, 531, 559, 10, 112, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14525, 546, 29, 0, 69, "Section"],
Cell[14557, 548, 356, 7, 96, "Text"],
Cell[14916, 557, 106, 3, 38, "Subsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15059, 565, 260, 4, 83, "Section"],
Cell[15322, 571, 21527, 282, 7974, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

